@@ -25,7 +25,6 @@
 #include <KGameRenderer>
 #include <KgThemeProvider>
 
-#include <QFileInfo>
 
 // note: this should be in sync with svg
 static inline char color2char(BallColor col)
@@ -60,7 +59,7 @@ int KLinesRenderer::m_selDuration(0);
 int KLinesRenderer::m_dieDuration(0);
 int KLinesRenderer::m_moveDuration(0);
 
-KLinesRenderer  *g_KLinesRenderer = NULL;
+KLinesRenderer  *g_KLinesRenderer = nullptr;
 
 void KLinesRenderer::Init()
 {
